@@ -133,19 +133,19 @@ void getPaths(void)
 		}
 		else
 		{
-			snprintf(confdir,(size_t)MAXPATH,"%s/%s",getenv("HOME"),GTKLPRC_USER);
+			snprintf((char*)confdir,(size_t)MAXPATH,"%s/%s",getenv("HOME"),GTKLPRC_USER);
 		}
 	}  	
 	else
 	{
-		z1=confdir;
-		z1+=strlen(confdir);
+		z1=(char*)confdir;
+		z1+=strlen((char*)confdir);
 		z1--;
 		if(*z1=='/')
 			*z1=(char)NULL;
 	}
 
-	snprintf(GTKLPRC,(size_t)MAXPATH,"%s/%s",confdir,GTKLPRC_GLOBAL);
+	snprintf((char*)GTKLPRC,(size_t)MAXPATH,"%s/%s",confdir,GTKLPRC_GLOBAL);
 
 }
 
@@ -447,11 +447,19 @@ void getOptions(char *printername,int which)
 			oldnumcopies=NumberOfCopies;
 		}
 
-		if(cupsGetOption("collate",act_printer->num_options,act_printer->options) != (char)NULL) {
+		if(cupsGetOption("collate",act_printer->num_options,act_printer->options) != NULL) {
 			if(strcasecmp(cupsGetOption("collate",act_printer->num_options,act_printer->options),"true") == 0)
 				collate=1;
+			else
+				collate=0;
+		} else if (ppdFindMarkedChoice(printerPPD,"Collate") != NULL) {
+			if(strcasecmp(ppdFindMarkedChoice(printerPPD,"Collate")->choice,"true") == 0)
+				collate=1;
+			else
+				collate=0;
 		}
 
+
 		if(cupsGetOption("landscape",act_printer->num_options,act_printer->options) != (char)NULL) {
 			if(strcasecmp(cupsGetOption("landscape",act_printer->num_options,act_printer->options),"true") == 0) 
 				wantLandscape=1;
@@ -849,7 +857,14 @@ int addAllOptions(cups_option_t **optionsptr, int num_options) {
 
 	option=NULL;
 
-	/* === At first the Command-Line opts, cause they could be
+	/* === At first PPD-Options, because they should be overwritten  
+	 *     by both command-line and interface entries === */
+	if(printerPPD != NULL) {
+		for(i1=printerPPD->num_groups, group=printerPPD->groups; i1>0; i1--, group++) 
+			num_options=addAllOptionsHelp(group, optionsptr, num_options);
+	}
+
+	/* === Then Command-Line opts, cause they could be
 				 overwritten by Interface-Entrys ======================*/
 
 	for(i1=num_commandline_opts, option=commandline_opts; i1>0; option++,i1--) {
@@ -865,8 +880,11 @@ int addAllOptions(cups_option_t **optionsptr, int num_options) {
 		snprintf(tmp,(size_t)MAXOPTLEN,"%i",NumberOfCopies);
 		num_options=cupsAddOption("copies",tmp,num_options,optionsptr);
 	}
+
 	if(collate == 1)
-		num_options=cupsParseOptions("collate",num_options,optionsptr);
+	  num_options=cupsAddOption("collate","true",num_options,optionsptr);
+	else
+	  num_options=cupsAddOption("collate","false",num_options,optionsptr);
 
 	/* Output */
 	if(wantRange == 1 && Range[0] != (unsigned char)NULL)
@@ -1080,13 +1098,6 @@ int addAllOptions(cups_option_t **optionsptr, int num_options) {
 	if(ExtraOpt[0] != (unsigned char)NULL)
 		num_options=cupsParseOptions(ExtraOpt,num_options,optionsptr);	
 
-
-	/* === Add PPD-Options === */
-	if(printerPPD != NULL) {
-		for(i1=printerPPD->num_groups, group=printerPPD->groups; i1>0; i1--, group++) 
-			num_options=addAllOptionsHelp(group, optionsptr, num_options);
-	}
-
 	return(num_options);
 }
 
