@@ -162,7 +162,7 @@ void outputTabSetDefaults(void)
 	/* Brightness */
 	gtk_adjustment_set_value(GTK_ADJUSTMENT(brightAdj),(int)brightness);	
 	/* Gamma */
-	gtk_adjustment_set_value(GTK_ADJUSTMENT(gammaAdj),(int)gamma);
+	gtk_adjustment_set_value(GTK_ADJUSTMENT(gammaAdj),(int)ggamma);
 
 }
 
