@@ -716,10 +716,10 @@ int printQueueUpdate (GtkWidget * widget, gpointer data)
 	      snprintf (queryLine[0], (size_t)MAXLINE, "%i", i1);
 	      break;
 	    }
-	  strncpy (queryLine[1], rankstr,(size_t)MAXLINE);
-	  strncpy (queryLine[2], jobuser,(size_t)MAXLINE);
+	  strncpy (queryLine[1], str2str(rankstr),(size_t)MAXLINE);
+	  strncpy (queryLine[2], str2str((char *)jobuser),(size_t)MAXLINE);
 	  snprintf (queryLine[3], (size_t)MAXLINE, "%d", jobid);
-	  strncpy (queryLine[4], jobname,(size_t)MAXLINE);
+	  strncpy (queryLine[4], str2str((char *)jobname),(size_t)MAXLINE);
 	  snprintf (queryLine[5], (size_t)MAXLINE, "%i", jobcopies);
 	  snprintf (queryLine[6], (size_t)MAXLINE, "%d", jobsize);
 
@@ -742,6 +742,9 @@ int printQueueUpdate (GtkWidget * widget, gpointer data)
 		}
 
 		if(nox == 0) {
+			/* honor button pushes */
+			while (gtk_events_pending())
+				gtk_main_iteration();
 	  	i1 = gtk_clist_append ((GtkCList *) queueList, g);
 
 		  if (selectedJob == jobid)
