@@ -86,6 +86,10 @@ GtkWidget *mainWindow;
 GtkWidget *passEntry;
 GtkWidget *loginEntry;
 
+#if GTK_MAJOR_VERSION != 1
+GtkWidget *progressBar=(GtkWidget *)NULL;
+#endif
+
 cups_lang_t *cupsLanguage;
 http_t *cupsHttp;
 
@@ -211,7 +215,9 @@ void getPrinters(int loop)
 	FILE *testfile2;
 	FILE *testfile3;
 	unsigned char ShowAllPrinter;
-
+#if GTK_MAJOR_VERSION != 1
+	double progFrac=1.0, progress=1.0;
+#endif
 	droppedPrinters=0;
 	ShowAllPrinter=TRUE;
 
@@ -247,6 +253,12 @@ testdir3=opendir(TMPPATH);
 if (testdir3 != (DIR *)NULL) {
   ShowAllPrinter=FALSE;
   closedir(testdir3); }
+
+#if GTK_MAJOR_VERSION != 1
+	progFrac=0.8/PrinterNum;
+	progress=0.1;
+#endif
+
 	for(i1=0;i1<=PrinterNum;i1++)
         {
 		if(DEBUG) {
@@ -255,6 +267,15 @@ if (testdir3 != (DIR *)NULL) {
 			else
 				printf("Name: %s - %s (%i)\n",dests[i1].name,dests[i1].instance,dests[i1].is_default);
 		}
+
+#if GTK_MAJOR_VERSION != 1
+		if(progressBar != (GtkWidget *)NULL) {
+			gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progressBar),progress);
+			while (gtk_events_pending())
+				gtk_main_iteration();
+			progress+=progFrac;
+		}
+#endif
 		if(dests[i1].instance == (char *)NULL)
 			snprintf(PrinterNames[i1-droppedPrinters],(size_t)DEF_PRN_LEN,"%s",dests[i1].name);
 		else
@@ -769,5 +790,3 @@ void hello( GtkWidget *widget,gpointer   data )
 				        g_print ("Hello World\n");
 }
 
-
-
